Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/Remmina/Remmina.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAntenore Gatta (tmow) <antenore@simbiosi.org>2021-02-16 18:53:55 +0300
committerAntenore Gatta (tmow) <antenore@simbiosi.org>2021-02-16 18:53:55 +0300
commit8f4ec0ac7950339fd460c91317e861b39e6145c5 (patch)
treefd33e3e46c5f45e9f5731eb96367f5ba68ed69db /src/remmina_ssh_plugin.c
parent3ac0346c101fa3fe4bae3d995fbd5a3302881720 (diff)
parent6e485eb485876118ba99fbff21b1c4cd002a6c81 (diff)
Merge branch 'kingu-master-patch-16116' into 'master'
Spelling: Colour See merge request Remmina/Remmina!2204
Diffstat (limited to 'src/remmina_ssh_plugin.c')
-rw-r--r--src/remmina_ssh_plugin.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/remmina_ssh_plugin.c b/src/remmina_ssh_plugin.c
index dda05f968..08c1c3915 100644
--- a/src/remmina_ssh_plugin.c
+++ b/src/remmina_ssh_plugin.c
@@ -79,9 +79,9 @@
enum color_schemes { LINUX, TANGO, GRUVBOX, SOLARIZED_DARK, SOLARIZED_LIGHT, XTERM, CUSTOM };
/** 16 color palettes in GdkRGBA format (red, green, blue, alpha).
* Text displayed in the first 8 colors (0-7) is meek (uses thin strokes).
* Text displayed in the second 8 colors (8-15) is bold (uses thick strokes).
**/
const GdkRGBA linux_palette[PALETTE_SIZE] = {
{ 0, 0, 0, 1 },
@@ -1418,7 +1418,7 @@ static gchar log_tips[] =
*/
static const RemminaProtocolSetting remmina_ssh_advanced_settings[] =
{
- { REMMINA_PROTOCOL_SETTING_TYPE_SELECT, "ssh_color_scheme", N_("Terminal color scheme"), FALSE, ssh_terminal_palette, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_SELECT, "ssh_color_scheme", N_("Terminal colour scheme"), FALSE, ssh_terminal_palette, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_SELECT, "ssh_charset", N_("Character set"), FALSE, ssh_charset_list, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_TEXT, "ssh_proxycommand", N_("SSH Proxy Command"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_TEXT, "ssh_kex_algorithms", N_("KEX (Key Exchange) algorithms"), FALSE, NULL, NULL },
@@ -79,9 +79,9 @@
enum color_schemes { LINUX, TANGO, GRUVBOX, SOLARIZED_DARK, SOLARIZED_LIGHT, XTERM, CUSTOM };
-/** 16 color palettes in GdkRGBA format (red, green, blue, alpha).
- * Text displayed in the first 8 colors (0-7) is meek (uses thin strokes).
- * Text displayed in the second 8 colors (8-15) is bold (uses thick strokes).
+/** 16 colour palettes in GdkRGBA format (red, green, blue, alpha).
+ * Text displayed in the first 8 colours (0-7) is meek (uses thin strokes).
+ * Text displayed in the second 8 colours (8-15) is bold (uses thick strokes).
**/
const GdkRGBA linux_palette[PALETTE_SIZE] = {